@@ -2,9 +2,10 @@
  * author: Achim Gaedke
  * created: January 2002
  * file: pygsl/src/multiminmodule.c
- * $Id: multiminmodule.c,v 1.5 2004/03/08 08:42:16 schnizer Exp $
+ * $Id: multiminmodule.c,v 1.6 2015/09/26 08:03:23 schnizer Exp $
  */
 #include <setjmp.h>
+#include <pygsl/transition.h>
 #include <pygsl/block_helpers.h>
 #include <pygsl/error_helpers.h>
 #include <pygsl/function_helpers.h>
@@ -465,7 +466,7 @@ PyGSL_multimin_name(PyGSL_multimin *self, PyObject *args)
 	  name = gsl_multimin_fdfminimizer_name(self->min.fdf);
      }
      FUNC_MESS_END();
-     return PyString_FromString(name);
+     return PyGSL_string_from_string(name);
 }
 
 static PyObject* 
@@ -627,6 +628,7 @@ static PyMethodDef PyGSL_multimin_fdfmethods[] = {
      {NULL, NULL, 0, NULL}           /* sentinel */
 };
 
+
 static PyObject* 
 PyGSL_multimin_init(PyObject *self, PyObject *args, 
 		    union pygsl_multimin_minimizer_type type, int t) 
@@ -828,8 +830,13 @@ static PyMethodDef multiminMethods[] = {
 
 
 
-void
-initmultimin(void)
+#ifdef PyGSL_PY3K
+PyObject *PyInit_multimin(void)
+#define RETVAL m
+#else /* PyGSL_PY3K */
+DL_EXPORT(void) inimultimin(void)
+#define RETVAL
+#endif /* PyGSL_PY3K */
 {
   PyObject* m, *dict, *item;
   m=Py_InitModule("multimin", multiminMethods);
@@ -847,7 +854,7 @@ initmultimin(void)
   if(!dict)
        goto fail;
   
-  if (!(item = PyString_FromString((char*)PyGSL_multimin_module_doc))){
+  if (!(item = PyGSL_string_from_string((char*)PyGSL_multimin_module_doc))){
        PyErr_SetString(PyExc_ImportError, 
 		       "I could not generate module doc string!");
        goto fail;
@@ -858,6 +865,8 @@ initmultimin(void)
        goto fail;
   }
 
+  return RETVAL
+
  fail:
-  return;
+  return RETVAL;
 }
