@@ -2,7 +2,7 @@
  * author: Achim Gaedke
  * created: January 2002
  * file: pygsl/src/multiminmodule.c
- * $Id: multimin.c,v 1.6 2008/10/25 20:45:04 schnizer Exp $
+ * $Id: multimin.c,v 1.9 2015/09/27 12:43:46 schnizer Exp $
  */
 #include <pygsl/solver.h>
 
@@ -135,20 +135,20 @@ PyGSL_multimin_set_f(PyGSL_solver *self, PyObject *pyargs, PyObject *kw)
 	  goto fail;
      }
 
-     gsl_x = gsl_vector_view_array_with_stride((double *)(xa->data), stride_recalc, xa->dimensions[0]);
+     gsl_x = gsl_vector_view_array_with_stride((double *)(PyArray_DATA(xa)), stride_recalc, PyArray_DIM(xa, 0));
      stepsa =  PyGSL_vector_check(steps, n, PyGSL_DARRAY_INPUT(5), &stride_recalc, NULL);
      if (stepsa == NULL){
 	  PyGSL_add_traceback(module, filename, __FUNCTION__, __LINE__ - 1);
 	  goto fail;
      }
-     gsl_steps = gsl_vector_view_array_with_stride((double *)(stepsa->data), stride_recalc, stepsa->dimensions[0]);
+     gsl_steps = gsl_vector_view_array_with_stride((double *)(PyArray_DATA(stepsa)), stride_recalc, PyArray_DIM(stepsa, 0));
 
      if (self->c_sys != NULL) {
 	  /* free the previous function and args */
 	  c_sys = self->c_sys;
      } else {
 	  /* allocate function space */
-	  c_sys=calloc(1, sizeof(gsl_multimin_function));
+       c_sys=(gsl_multimin_function *)calloc(1, sizeof(gsl_multimin_function));
 	  if (c_sys == NULL) {
 	       pygsl_error("Could not allocate the object for the minimizer function", 
 			 filename, __LINE__ - 3, GSL_ENOMEM);
@@ -230,7 +230,7 @@ PyGSL_multimin_set_fdf(PyGSL_solver *self, PyObject *pyargs, PyObject *kw)
 	  PyGSL_add_traceback(module, filename, __FUNCTION__, __LINE__ - 1);
 	  goto fail;
      }
-     gsl_x = gsl_vector_view_array_with_stride((double *)(xa->data), stride_recalc, xa->dimensions[0]);
+     gsl_x = gsl_vector_view_array_with_stride((double *)(PyArray_DATA(xa)), stride_recalc, PyArray_DIM(xa, 0));
 
 
      if (self->c_sys != NULL) {
@@ -501,6 +501,11 @@ static PyMethodDef mMethods[] = {
      {NULL, NULL, 0, NULL}
 };
 
+#ifdef __cplusplus
+extern "C"
+#endif
+
+
 void
 initmultimin(void)
 {
@@ -519,7 +524,7 @@ initmultimin(void)
      assert(PyGSL_API);
 
 
-     if (!(item = PyString_FromString((char*)PyGSL_multimin_module_doc))){
+     if (!(item = PyGSL_string_from_string((char*)PyGSL_multimin_module_doc))){
 	  PyErr_SetString(PyExc_ImportError, 
 			  "I could not generate module doc string!");
 	  goto fail;
