@@ -1,6 +1,8 @@
 #include "solver_intern.h"
 #include <pygsl/general_helpers.h>
 #include <pygsl/block_helpers.h>
+#include <pygsl/error_helpers.h>
+#include <pygsl/string_helpers.h>
 #if 0
 #include <pygsl/function_helpers.h>
 #endif
@@ -52,7 +54,7 @@ PyGSL_solver_name(PyGSL_solver *self, PyObject *args)
      if(self->mstatic->cmethods.name == NULL)
 	  PyGSL_ERROR_NULL("Can not restart a solver of this type!", GSL_ESANITY);
      ctmp = self->mstatic->cmethods.name(self->solver);
-     tmp =  PyString_FromString(ctmp);
+     tmp =  PyGSL_string_from_string(ctmp);
      FUNC_MESS_END();
      return tmp;
 }
@@ -74,7 +76,7 @@ PyGSL_solver_iterate(PyGSL_solver *self, PyObject *args)
      if(PyGSL_ERROR_FLAG(tmp) != GSL_SUCCESS)
 	  return NULL;
 
-     return PyInt_FromLong((long) tmp);
+     return PyLong_FromLong((long) tmp);
 }
 
 
@@ -162,7 +164,7 @@ static PyObject *
 PyGSL_solver_type(PyGSL_solver * self, PyObject *unused)
 {
      assert(self->mstatic->type_name);
-     return PyString_FromString(self->mstatic->type_name);
+     return PyGSL_string_from_string(self->mstatic->type_name);
 }
 
 static PyMethodDef solver_methods[] = {
@@ -172,13 +174,15 @@ static PyMethodDef solver_methods[] = {
      {"type",    (PyCFunction) PyGSL_solver_type,    METH_NOARGS, NULL},
      {NULL, NULL, 0, NULL}
 };
+
+#ifndef PyGSL_PY3K
 static PyObject *
 PyGSL_solver_getattr(PyGSL_solver * self, char * name)
 {
      PyObject *tmp = NULL;
      FUNC_MESS_BEGIN();
      if(self->mstatic->pymethods)
-	  tmp = Py_FindMethod(self->mstatic->pymethods, (PyObject *) self, name);
+       tmp = Py_FindMethod(self->mstatic->pymethods, (PyObject *) self, name);
      if(tmp == NULL){
 	  PyErr_Clear();
 	  tmp = Py_FindMethod(solver_methods, (PyObject *) self, name);
@@ -186,7 +190,50 @@ PyGSL_solver_getattr(PyGSL_solver * self, char * name)
      FUNC_MESS_END();
      return tmp;
 }
+#endif /* PyGSL_PY3K */
 
+#ifdef PyGSL_PY3K
+static PyTypeObject PyGSL_solver_pytype = {
+	PyObject_HEAD_INIT(NULL)
+	"PyGSL_solver",                    /* tp_name */
+	sizeof(PyGSL_solver),              /* tp_basicsize */
+	0,                                          /* tp_itemsize */
+	(destructor) PyGSL_solver_dealloc, /* tp_dealloc */
+	0,                       /* tp_print */
+	0,                       /* tp_getattr */
+	0,                       /* tp_setattr */
+	0,                       /* tp_reserved */
+	0,                       /* tp_repr */
+	0,                       /* tp_as_number */
+	0,                       /* tp_as_sequence */
+	0,                       /* tp_as_mapping */
+	0,                       /* tp_hash */
+	0,                       /* tp_call */
+	0,                       /* tp_str */
+	0,                       /* tp_getattro */
+	0,                       /* tp_setattro */
+	0,                       /* tp_as_buffer */
+	Py_TPFLAGS_DEFAULT,      /* tp_flags */
+	(char *)PyGSL_solver_type_doc, /* tp_doc */
+	0,                       /* tp_traverse */
+	0,                       /* tp_clear */
+	0,                       /* tp_richcompare */
+	0,                       /* tp_weaklistoffset */
+	0,                       /* tp_iter */
+	0,                       /* tp_iternext */
+	solver_methods,          /* tp_methods */
+	0,                       /* tp_members */
+	0,                       /* tp_getset */
+	0,                       /* tp_base */
+	0,                       /* tp_dict */
+	0,                       /* tp_descr_get */
+	0,                       /* tp_descr_set */
+	0,                       /* tp_dictoffset */
+	0,                       /* tp_init */
+	0,                       /* tp_alloc */
+	0,                       /* tp_new */
+};
+#else /* PyGSL_PY3K */
 static PyTypeObject PyGSL_solver_pytype = {
   PyObject_HEAD_INIT(NULL)	 /* fix up the type slot in initcrng */
   0,				 /* ob_size */
@@ -217,6 +264,7 @@ static PyTypeObject PyGSL_solver_pytype = {
   0L,				/* tp_flags */
   (char *) PyGSL_solver_type_doc		/* tp_doc */
 };
+#endif /* PyGSL_PY3K */
 
 PyGSL_solver* 
 _PyGSL_solver_init(const struct _SolverStatic *mstatic) 
@@ -255,7 +303,6 @@ _PyGSL_solver_init(const struct _SolverStatic *mstatic)
 	  solver_o->problem_dimensions[i] = -1;
      }
 
-     DEBUG_MESS(3, "refcount = %d", solver_o->ob_refcnt);
      FUNC_MESS_END();
      return solver_o;
  fail:
@@ -543,11 +590,11 @@ PyGSL_solver_set_f(PyGSL_solver *self, PyObject *pyargs, PyObject *kw,
      
      /* initialize the function struct */
      if(isfdf == 0){
-	  f_sys = c_sys;
+          f_sys = (gsl_function *) c_sys;
 	  f_sys->function=PyGSL_gsl_function;
 	  f_sys->params=(void*)self;
      }else{
-	  fdf_sys = c_sys;
+	  fdf_sys = (gsl_function_fdf *) c_sys;
 	  fdf_sys->f=PyGSL_gsl_function;
 	  fdf_sys->df=PyGSL_gsl_function_df;
 	  fdf_sys->fdf=PyGSL_gsl_function_fdf;
@@ -558,10 +605,10 @@ PyGSL_solver_set_f(PyGSL_solver *self, PyObject *pyargs, PyObject *kw,
 	  self->isset = 1;
 	  if(isfdf == 0){
 	       DEBUG_MESS(3, "Calling f isfdf = %d", isfdf);
-	       flag = ((set_m_ddd_t) fptr)(self->solver, c_sys, x0, lower, upper);
+	       flag = ((set_m_ddd_t) fptr)(self->solver, f_sys, x0, lower, upper);
 	  }else{
 	       DEBUG_MESS(3, "Calling fdf isfdf = %d", isfdf);
-	       flag = ((set_m_d_t) fptr)(self->solver, c_sys, x0);
+	       flag = ((set_m_d_t) fptr)(self->solver, f_sys, x0);
 	  }
 	  if(PyGSL_ERROR_FLAG(flag) != GSL_SUCCESS){
 	       goto fail;
@@ -630,8 +677,8 @@ PyGSL_solver_n_set(PyGSL_solver *self, PyObject *pyargs, PyObject *kw,
 	  line = __LINE__ - 2;
 	  goto fail;
      }
-     gsl_x = gsl_vector_view_array_with_stride((double *)(xa->data), stride,
-					       xa->dimensions[0]);
+     gsl_x = gsl_vector_view_array_with_stride((double *)PyArray_DATA(xa), stride,
+					       PyArray_DIM(xa, 0));
 
 
      if (self->c_sys != NULL) {
@@ -746,8 +793,8 @@ PyGSL_solver_vd_i(PyObject * self, PyObject *args, int_f_vd_t func)
 	  PyGSL_add_traceback(module, filename, __FUNCTION__, __LINE__ - 1);
 	  return NULL;
      }
-     gradient = gsl_vector_view_array_with_stride((double *)(ga->data), stride_recalc,
-						  ga->dimensions[0]);
+     gradient = gsl_vector_view_array_with_stride((double *)(PyArray_DATA(ga)), stride_recalc,
+						  PyArray_DIM(ga, 0));
      flag = func(&gradient.vector, epsabs);
      FUNC_MESS_END();
      return PyGSL_ERROR_FLAG_TO_PYINT(flag);
@@ -774,15 +821,16 @@ PyGSL_solver_vvdd_i(PyObject * self, PyObject * args, int_f_vvdd_t func)
 	  line = __LINE__ - 4;
 	  goto fail;
      }
-     dx = gsl_vector_view_array_with_stride((double *)(dx_a->data), stride, dx_a->dimensions[0]);
+     
+     dimension = PyArray_DIM(dx_a, 0);
+     dx = gsl_vector_view_array_with_stride((double *)(PyArray_DATA(dx_a)), stride, PyArray_DIM(dx_a, 0));
 
-     dimension = dx_a->dimensions[0];
      x_a = PyGSL_vector_check(x_o, dimension, PyGSL_DARRAY_CINPUT(2), &stride,  NULL);
      if(x_a == NULL){
 	  line = __LINE__ - 4;
 	  goto fail;
      }
-     x = gsl_vector_view_array_with_stride((double *)(x_a->data), stride, x_a->dimensions[0]);
+     x = gsl_vector_view_array_with_stride((double *)(PyArray_DATA(x_a)), stride, PyArray_DIM(x_a, 0));
      flag = func(&(dx.vector), &(x.vector), epsabs, epsrel);
      Py_DECREF(x_a);
      Py_DECREF(dx_a);
@@ -885,7 +933,7 @@ PyGSL_solver_GetSet(PyObject *self, PyObject *args, void * address, enum PyGSL_G
 	  ret = PyFloat_FromDouble(*((double *) address));
 	  break;
      case PyGSL_MODE_INT:
-	  ret = PyInt_FromLong(((long) *((int *) address)));
+          ret = PyLong_FromLong(((long) *((int *) address)));
 	  break;
      case PyGSL_MODE_SIZE_T:
 	  ret = PyLong_FromUnsignedLong(((unsigned long) *((size_t *) address)));
@@ -942,18 +990,57 @@ init_api(void)
      FUNC_MESS_END();
 }
 
-void
-initsolver(void)
+
+
+#ifdef PyGSL_PY3K
+static struct PyModuleDef moduledef = {
+        PyModuleDef_HEAD_INIT,
+        "pygsl.testing.solver",
+        NULL,
+        -1,
+        solverMethods,
+        NULL,
+        NULL,
+        NULL,
+        NULL
+};
+#endif 
+
+#ifdef __cplusplus
+extern "C"
+#endif
+
+
+#ifdef PyGSL_PY3K
+PyObject *PyInit_solver(void)
+#define RETVAL m
+#else /* PyGSL_PY3K */
+DL_EXPORT(void) initsolver(void)
+#define RETVAL
+#endif /* PyGSL_PY3K */
 {
-  PyObject* m, *dict, *item;
+  PyObject* m = NULL, *dict, *item;
 
   FUNC_MESS_BEGIN();
+
+#ifdef PyGSL_PY3K
+  m = PyModule_Create(&moduledef);
+#else /* PyGSL_PY3K */    
   m=Py_InitModule("solver", solverMethods);
+#endif /* PyGSL_PY3K */
+
+  if(m == NULL)
+    goto fail;
+
   init_pygsl();
 
-
   /* init multimin type */
+#ifdef PyGSL_PY3K
+  if (PyType_Ready(&PyGSL_solver_pytype) < 0)
+		return NULL;
+#else /* PyGSL_PY3K */    
   PyGSL_solver_pytype.ob_type  = &PyType_Type;
+#endif /* PyGSL_PY3K */
 
   init_api();
 
@@ -966,7 +1053,7 @@ initsolver(void)
   if(!dict)
        goto fail;
   
-  if (!(item = PyString_FromString((char*)PyGSL_solver_module_doc))){
+  if (!(item = PyGSL_string_from_string((char*)PyGSL_solver_module_doc))){
        PyErr_SetString(PyExc_ImportError, 
 		       "I could not generate module doc string!");
        goto fail;
@@ -977,9 +1064,10 @@ initsolver(void)
        goto fail;
   }
   FUNC_MESS_END();
+  return RETVAL;
 
  fail:
   FUNC_MESS("FAIL");
-  return;
+  return RETVAL;
 
 }
