@@ -1,8 +1,6 @@
 import unittest
 import math
-import pygsl.histogram
 import warnings
-import exceptions
 import pygsl.errors
 import tempfile
 import os
